==> fjp-0.1.0.tgz: package/es/monads/Maybe/index.js <==
var _createClass = /*#__PURE__*/ function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

var Maybe = /*#__PURE__*/function () {
  function Maybe() {
    _classCallCheck(this, Maybe);
  }

  _createClass(Maybe, [{
    key: "flatten",
    value: function flatten() {
      return this;
    }
  }, {
    key: "join",
    value: function join() {
      return this;
    }
  }, {
    key: "filter",
    value: function filter() {
      return this;
    }
  }, {
    key: "map",
    value: function map() {
      return this;
    }
  }, {
    key: "chain",
    value: function chain(fn) {
      return this.map(fn).flatten();
    }
  }, {
    key: "isNothing",
    get: function get() {
      return false;
    }
  }, {
    key: "isJust",
    get: function get() {
      return false;
    }
  }], [{
    key: "of",
    value: function of(x) {
      // eslint-disable-next-line no-use-before-define
      return x !== undefined && x !== null ? new _Just(x) : new Nothing();
    }
  }, {
    key: "Just",
    value: function Just(x) {
      // eslint-disable-next-line no-use-before-define
      return new _Just(x);
    }
  }, {
    key: "None",
    value: function None() {
      // eslint-disable-next-line no-use-before-define
      return new Nothing();
    }
  }, {
    key: "fromNullable",
    value: function fromNullable(x) {
      return Maybe.of(x);
    }
  }, {
    key: "lift",
    value: function lift(fn, x) {
      return Maybe.of(x).map(fn);
    }
  }]);

  return Maybe;
}();

var _Just = /*#__PURE__*/function (_Maybe) {
  _inherits(_Just, _Maybe);

  function _Just(val) {
    _classCallCheck(this, _Just);

    var _this = _possibleConstructorReturn(this, (_Just.__proto__ || Object.getPrototypeOf(_Just)).call(this));

    _this._val = val;
    return _this;
  }

  _createClass(_Just, [{
    key: "map",
    value: function map(fn) {
      return Maybe.of(fn(this._val));
    }
  }, {
    key: "flatten",
    value: function flatten() {
      if (!(this._val instanceof _Just)) {
        return this;
      }

      return this._val.flatten();
    }
  }, {
    key: "join",
    value: function join() {
      return this.flatten();
    }
  }, {
    key: "orElse",
    value: function orElse() {
      return this._val;
    }
  }, {
    key: "filter",
    value: function filter(fn) {
      Maybe.of(fn(this._val) ? this._val : null);
    }
  }, {
    key: "toString",
    value: function toString() {
      return "Maybe.Just(" + this._val + ")";
    }
  }, {
    key: "value",
    get: function get() {
      return this._val;
    }
  }, {
    key: "isJust",
    get: function get() {
      return true;
    }
  }]);

  return _Just;
}(Maybe);

var Nothing = /*#__PURE__*/function (_Maybe2) {
  _inherits(Nothing, _Maybe2);

  function Nothing() {
    _classCallCheck(this, Nothing);

    return _possibleConstructorReturn(this, (Nothing.__proto__ || Object.getPrototypeOf(Nothing)).call(this));
  }

  _createClass(Nothing, [{
    key: "orElse",
    value: function orElse(other) {
      return other;
    }
  }, {
    key: "toString",
    value: function toString() {
      return 'Maybe.Nothing';
    }
  }, {
    key: "value",
    get: function get() {
      throw new TypeError("Can't extract the value of a Nothing");
    }
  }, {
    key: "isNothing",
    get: function get() {
      return true;
    }
  }]);

  return Nothing;
}(Maybe);

export default Maybe;

==> fjp-0.2.3.tgz: package/es/monads/Maybe/index.js <==
import _Object$getPrototypeOf from "babel-runtime/core-js/object/get-prototype-of";
import _possibleConstructorReturn from "babel-runtime/helpers/possibleConstructorReturn";
import _inherits from "babel-runtime/helpers/inherits";
import _classCallCheck from "babel-runtime/helpers/classCallCheck";
import _createClass from "babel-runtime/helpers/createClass";

var Maybe = /*#__PURE__*/function () {
  function Maybe() {
    _classCallCheck(this, Maybe);
  }

  _createClass(Maybe, [{
    key: "flatten",
    value: function flatten() {
      return this;
    }
  }, {
    key: "join",
    value: function join() {
      return this;
    }
  }, {
    key: "filter",
    value: function filter() {
      return this;
    }
  }, {
    key: "map",
    value: function map() {
      return this;
    }
  }, {
    key: "chain",
    value: function chain(fn) {
      return this.map(fn).flatten();
    }
  }, {
    key: "isNothing",
    get: function get() {
      return false;
    }
  }, {
    key: "isJust",
    get: function get() {
      return false;
    }
  }], [{
    key: "of",
    value: function of(x) {
      // eslint-disable-next-line no-use-before-define
      return x !== undefined && x !== null ? new _Just(x) : new Nothing();
    }
  }, {
    key: "Just",
    value: function Just(x) {
      // eslint-disable-next-line no-use-before-define
      return new _Just(x);
    }
  }, {
    key: "None",
    value: function None() {
      // eslint-disable-next-line no-use-before-define
      return new Nothing();
    }
  }, {
    key: "fromNullable",
    value: function fromNullable(x) {
      return Maybe.of(x);
    }
  }, {
    key: "lift",
    value: function lift(fn, x) {
      return Maybe.of(x).map(fn);
    }
  }]);

  return Maybe;
}();

var _Just = /*#__PURE__*/function (_Maybe) {
  _inherits(_Just, _Maybe);

  function _Just(val) {
    _classCallCheck(this, _Just);

    var _this = _possibleConstructorReturn(this, (_Just.__proto__ || _Object$getPrototypeOf(_Just)).call(this));

    _this._val = val;
    return _this;
  }

  _createClass(_Just, [{
    key: "map",
    value: function map(fn) {
      return Maybe.of(fn(this._val));
    }
  }, {
    key: "flatten",
    value: function flatten() {
      if (!(this._val instanceof _Just)) {
        return this;
      }

      return this._val.flatten();
    }
  }, {
    key: "join",
    value: function join() {
      return this.flatten();
    }
  }, {
    key: "orElse",
    value: function orElse() {
      return this._val;
    }
  }, {
    key: "filter",
    value: function filter(fn) {
      Maybe.of(fn(this._val) ? this._val : null);
    }
  }, {
    key: "toString",
    value: function toString() {
      return "Maybe.Just(" + this._val + ")";
    }
  }, {
    key: "value",
    get: function get() {
      return this._val;
    }
  }, {
    key: "isJust",
    get: function get() {
      return true;
    }
  }]);

  return _Just;
}(Maybe);

var Nothing = /*#__PURE__*/function (_Maybe2) {
  _inherits(Nothing, _Maybe2);

  function Nothing() {
    _classCallCheck(this, Nothing);

    return _possibleConstructorReturn(this, (Nothing.__proto__ || _Object$getPrototypeOf(Nothing)).call(this));
  }

  _createClass(Nothing, [{
    key: "orElse",
    value: function orElse(other) {
      return other;
    }
  }, {
    key: "toString",
    value: function toString() {
      return 'Maybe.Nothing';
    }
  }, {
    key: "value",
    get: function get() {
      throw new TypeError("Can't extract the value of a Nothing");
    }
  }, {
    key: "isNothing",
    get: function get() {
      return true;
    }
  }]);

  return Nothing;
}(Maybe);

export default Maybe;
